@@ -72,6 +72,7 @@ static constexpr ModFormatInfo modFormatInfo[] =
 	{ UL_("Digital Tracker"),                    "dtm" },
 	{ UL_("Farandole Composer"),                 "far" },
 	{ UL_("FM Tracker"),                         "fmt" },
+	{ UL_("ProTracker"),                         "fst" },
 	{ UL_("Imago Orpheus"),                      "imf" },
 	{ UL_("Ice Tracker"),                        "ice" },
 #ifdef MPT_EXTERNAL_SAMPLES
@@ -103,7 +104,7 @@ static constexpr ModFormatInfo modFormatInfo[] =
 	{ UL_("Graoumf Tracker 1 / 2"),              "gt2"},
 	{ UL_("UltraTracker"),                       "ult" },
 	{ UL_("Mod's Grave"),                        "wow" },
-	{ UL_("Imperium Galactica"),                 "xmf" },
+	{ UL_("Astroidea XMF"),                      "xmf" },
 	// converted formats (no MODTYPE)
 	{ UL_("General Digital Music"),              "gdm" },
 	{ UL_("Un4seen MO3"),                        "mo3" },
